// FIXME: Ok questo file è abbastanza self-contained però sarebbe meglio riorganizzarlo un po' in modo da non avere così tante variabili globali

/*
Un'idea (spastica) sarebbe che `addTooltipElementListener` si aspetta che il callback dell'evento `false` se non ha nulla da mostrare oppure una funzione che riceve come parametro l'elemento della tooltip (in questo modo `setTooltip(callback)` non servirebbe più e setTooltipText(text) diventerebbe una funzione parziale che ritorna una "mounting function").

In questo modo:
- `setTooltip` non esisterebbe più e ci sarebbero meno "momenti" in cui il testo della tooltip può cambiare.
- Anche `resetTooltip` non esisterebbe più perché semplicemente la tooltip scomparirebbe se tutti i listener ritornano `false`.
- `setTooltipText` diventerebbe una funzione "pura rispetto al mondo esterno" (che modifica solo cose nel suo scope) che è sempre meglio di modificare variabili globali.
*/

const LISTENERS = []
const $tooltip = document.querySelector('#tooltip')

export function attachTooltip() {
    document.body.addEventListener('mousemove', e => {
        $tooltip.style.setProperty('--x', 10 + e.pageX + 'px')
        $tooltip.style.setProperty('--y', 10 + e.pageY + 'px')

        for (const listener of LISTENERS) {
            if (listener(e.target)) {
                return
            }
        }

        resetTooltip()
    })

    resetTooltip()
}

/**
 * addTooltipElementListener attaches a listener on the mouse moved event. The listener should return true only if it needs the tooltip to be visible (TODO: change this to return a mounting function), otherwise it should return false.
 * @param {*} callbackFn
 */
export function addTooltipElementListener(callbackFn) {
    LISTENERS.push(callbackFn)
}

/**
 * setTooltip shows the tooltip and calls the given callback with the tooltip element to
 * let the caller modify the tooltip as preferred.
 */
export function setTooltip(mountFn) {
    $tooltip.classList.remove('hidden')

    mountFn($tooltip)

    RESET_DIRTY = true
}

let TEXT_BUFFER = null
export function setTooltipText(text) {
    setTooltip($t => {
        if (text !== TEXT_BUFFER) {
            $t.innerText = text
            TEXT_BUFFER = text
        }
    })
}

let RESET_DIRTY = true
export function resetTooltip() {
    if (!RESET_DIRTY) return

    TEXT_BUFFER = null
    $tooltip.classList.add('hidden')

    while ($tooltip.firstChild) {
        $tooltip.firstChild.remove()
    }

    RESET_DIRTY = false
}
